from distutils.core import setup
setup(
        name='tamako',
        version='5.0',
        description='张力元',
        author='tamako',
        author_email='2415075961@qq.com',
        py_modules=['debug.print']
)

